@@ -3,5 +3,5 @@ class Items(object):
         self._client = client
 
     def get_item_search(self, params=None, **kwargs):
-        url = 'itemSearch'
-        return self._client._get(self._client.BASE_URL + url, params=params, **kwargs)
\ No newline at end of file
+        url = "itemSearch"
+        return self._client._get(self._client.BASE_URL + url, params=params, **kwargs)
