@@ -3,5 +3,5 @@ class Recents(object):
         self._client = client
 
     def get_recent_changes(self, params=None, **kwargs):
-        url = 'recents'
+        url = "recents"
         return self._client._get(self._client.BASE_URL + url, params=params, **kwargs)
